Improve this doc

# `ngResource`

# ngResource

The `ngResource` module provides interaction support with RESTful services via the $resource service.

See `$resource` for usage.

## Installation

First include `angular-resource.js` in your HTML:

        <script src="angular.js">
        <script src="angular-resource.js">

You can download this file from the following places:

- Google CDN
  e.g. `//ajax.googleapis.com/ajax/libs/angularjs/X.Y.Z/angular-resource.js`
- Bower
  e.g.

      bower install angular-resource@X.Y.Z

- code.angularjs.org
  e.g.

      "//code.angularjs.org/X.Y.Z/angular-resource.js"

where X.Y.Z is the AngularJS version you are running.

Then load the module in your application by adding it as a dependent module:

      angular.module('app', ['ngResource']);

With that you're ready to get started!

## Module Components

### Service

Name | Description
--- | ---
$resource | A factory which creates a resource object that lets you interact with RESTful server-side data sources.